Re: [PATCH 13/68] libata: revamp ata_get_cmd_descript()

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



On 10.12.2021 10:28, Hannes Reinecke wrote:

Rename ata_get_cmd_descrip() to ata_get_cmd_name() and simplify
it to return 'unknown' instead of NULL.

   "unknown"?

Signed-off-by: Hannes Reinecke <hare@xxxxxxx>

[...]
diff --git a/drivers/ata/libata-eh.c b/drivers/ata/libata-eh.c
index 69f51616d8bd..29a64059d3a1 100644
--- a/drivers/ata/libata-eh.c
+++ b/drivers/ata/libata-eh.c
@@ -2080,16 +2080,15 @@ void ata_eh_autopsy(struct ata_port *ap)
  }
/**
  *	ata_get_cmd_descript - get description for ATA command

   s/description/name/?

   *	@command: ATA command code to get description for

   Here as well?

   *
- *	Return a textual description of the given command, or NULL if the
- *	command is not known.
+ *	Return a textual description of the given command or "unknown"

   And here?

   *
   *	LOCKING:
   *	None
   */
-const char *ata_get_cmd_descript(u8 command)
+const char *ata_get_cmd_name(u8 command)
  {
  #ifdef CONFIG_ATA_VERBOSE_ERROR
  	static const struct
@@ -2080,16 +2080,15 @@ void ata_eh_autopsy(struct ata_port *ap)
  }
/**
- *	ata_get_cmd_descript - get description for ATA command
+ *	ata_get_cmd_name - get description for ATA command

   s/description/name/?
[...]

MBR, Sergey



[Index of Archives]     [Linux Filesystems]     [Linux SCSI]     [Linux RAID]     [Git]     [Kernel Newbies]     [Linux Newbie]     [Security]     [Netfilter]     [Bugtraq]     [Yosemite News]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Samba]     [Device Mapper]

  Powered by Linux